@@ -11,6 +11,7 @@ LOG_DIR=/var/log/aif
 LOGFILE=$LOG_DIR/aif.log
 DISCLAIMER="Note that despite our careful coding and proper testing there may still be bugs in this software.\n
 When you are doing this installation on a system where some data must be preserved, we suggest you make a backup first"
+export LC_COLLATE=C # for consistent sorting behavior
 
 ###### Early bootstrap ######
 
@@ -33,6 +34,8 @@ process_args ()
 ###### perform actual logic ######
 echo "Welcome to $TITLE"
 
+[[ $EUID -ne 0 ]] && die_error "You must have root privileges to run AIF"
+
 mount -o remount,rw / &>/dev/null 
 cleanup_runtime
 
