@@ -1,6 +1,5 @@
 #!/bin/bash
 
-
 # FORMAT DEFINITIONS:
 
 # -- formats used to interface with this library --
@@ -29,8 +28,6 @@
 modprobe -q dm-crypt || show_warning modprobe 'Could not modprobe dm-crypt. no support for disk encryption'
 modprobe -q aes-i586 || modprobe -q aes-x86-64 || show_warning modprobe 'Could not modprobe aes-i586 or aes-x86-64. no support for disk encryption'
 
-
-
 TMP_DEV_MAP=$RUNTIME_DIR/aif-dev.map
 TMP_FSTAB=$RUNTIME_DIR/aif-fstab
 TMP_PARTITIONS=$RUNTIME_DIR/aif-partitions
@@ -141,8 +138,8 @@ finddisks() {
             [ "$2" ] && echo $2
         fi
     done  
-    #scsi/sata devices
-    for dev in $(ls | egrep '^sd'); do
+    #scsi/sata devices, and virtio blockdevices (/dev/vd*)
+    for dev in $(ls | egrep '^[sv]d'); do
         # TODO: what is the significance of 5? ASKDEV
         if ! [ "$(cat $dev/device/type)" = "5" ]; then
             echo -n "/dev/$dev$3"
@@ -368,7 +365,7 @@ partition()
 	# invoke sfdisk
 	debug 'FS' "Partition calls: sfdisk $DEVICE -uM >$LOG 2>&1 <<< $sfdisk_input"
 	printk off
-	sfdisk $DEVICE -uM >$LOG 2>&1 <<EOF
+	sfdisk -D $DEVICE -uM >$LOG 2>&1 <<EOF
 $sfdisk_input
 EOF
     if [ $? -gt 0 ]; then
@@ -763,10 +760,12 @@ process_filesystem ()
 		local _uuid="$(getuuid $part)"
 		if [ -n "${_uuid}" ]; then
 			_device="UUID=${_uuid}"
+		else
+			_device=$part
 		fi
-		if ! grep -q "$part $fs_mountpoint $fs_type defaults 0 " $TMP_FSTAB 2>/dev/null #$TMP_FSTAB may not exist yet
+		if ! grep -q "$_device $fs_mountpoint $fs_type defaults 0 " $TMP_FSTAB 2>/dev/null #$TMP_FSTAB may not exist yet
 		then
-			echo -n "$part $fs_mountpoint $fs_type defaults 0 " >> $TMP_FSTAB
+			echo -n "$_device $fs_mountpoint $fs_type defaults 0 " >> $TMP_FSTAB
 			if [ "$fs_type" = "swap" ]; then
 				echo "0" >>$TMP_FSTAB
 			else
@@ -871,5 +870,3 @@ mdraid_all-slaves ()
     done
     echo $slaves
 }
-
-
