@@ -14,16 +14,29 @@ run_mkinitcpio()
 	target_special_fs off
 
 	# alert the user to fatal errors
-	[ $mkinitcpio_exitcode -ne 0 ] && show_warning "MKINITCPIO FAILED - SYSTEM MAY NOT BOOT" "$TMP_MKINITCPIO_LOG" text
-	return $mkinitcpio_exitcode
+	[ $CONTROLLED_EXIT -ne 0 ] && show_warning "MKINITCPIO FAILED - SYSTEM MAY NOT BOOT" "$TMP_MKINITCPIO_LOG" text
+	return $CONTROLLED_EXIT
 }
 
 
 # installpkg(). taken from setup. modified bigtime
 # performs package installation to the target system
 installpkg() {
-	ALL_PACKAGES=$var_TARGET_PACKAGES
-	[ -n "$TARGET_GROUPS" ] && ALL_PACKAGES="$ALL_PACKAGES "`list_packages group "$TARGET_GROUPS" | awk '{print $2}'`
+	ALL_PACKAGES=
+	[ -n "$var_TARGET_GROUPS" ] && ALL_PACKAGES=`list_packages group "$var_TARGET_GROUPS" | awk '{print $2}'`
+	if [ -n "$var_TARGET_PACKAGES_EXCLUDE" ]
+	then
+		for excl in $var_TARGET_PACKAGES_EXCLUDE
+		do
+			ALL_PACKAGES=${ALL_PACKAGES//$excl/}
+		done
+	fi
+
+	if [ -n "$var_TARGET_PACKAGES" ]
+	then
+		[ -n "$ALL_PACKAGES" ] && ALL_PACKAGES="$ALL_PACKAGES $var_TARGET_PACKAGES"
+		[ -z "$ALL_PACKAGES" ] && ALL_PACKAGES=$var_TARGET_PACKAGES
+	fi
 	ALL_PACKAGES=`echo $ALL_PACKAGES`
 	[ -z "$ALL_PACKAGES" ] && die_error "No packages/groups specified to install"
 
@@ -35,7 +48,7 @@ installpkg() {
 	run_controlled pacman_installpkg "$PACMAN_TARGET --noconfirm -S $ALL_PACKAGES" $TMP_PACMAN_LOG "Installing... Please Wait" 
 
 	local _result=''
-	if [ ${pacman_installpkg_exitcode} -ne 0 ]; then
+	if [ $CONTROLLED_EXIT -ne 0 ]; then
 		_result="Installation Failed (see errors below)"
 		echo -e "\nPackage Installation FAILED." >>$TMP_PACMAN_LOG
 	else
@@ -48,7 +61,7 @@ installpkg() {
 	target_special_fs off
 	sync
 
-	return ${pacman_installpkg_exitcode}
+	return $CONTROLLED_EXIT
 }
 
 
