@@ -53,6 +53,7 @@ prefill_configs () {
 			sed -i '/^HOOKS/ s/keymap/usbinput keymap/' ${var_TARGET_DIR}/etc/mkinitcpio.conf
 		fi
 	fi
+	# TODO: we should probably update /etc/crypttab if the user has non-/ encrypted disks.
 }
 
 interactive_configure_system()
@@ -71,7 +72,8 @@ interactive_configure_system()
 		[ -n "$FILE" ] &&  DEFAULT="$FILE"
 		helptext="\nNote that if you want to change any file not listed here (unlikely) you can go to another tty and update ${var_TARGET_DIR}/etc/<filename> yourself"
 		grep -q '^/dev/mapper' $TMP_FSTAB && helptext="$helptext\n/dev/mapper/ users: Pay attention to HOOKS in mkinitcpio.conf"
-		ask_option $DEFAULT "Configuration" "$helptext" required \
+		grep -q dm_crypt $TMP_BLOCKDEVICES && crypt="/etc/crypttab Encryption_settings_for_non-root_encrypted_disks" # this simple grep will give some false positives. but oh well.
+		ask_option $DEFAULT "Configuration" "$helptext" required $crypt \
 		"/etc/rc.conf"                  "System Config" \
 		"/etc/fstab"                    "Filesystem Mountpoints" \
 		"/etc/mkinitcpio.conf"          "Initramfs Config" \
@@ -242,10 +244,13 @@ interactive_autoprepare()
 		notify "Available Disks:\n\n$(_getavaildisks)\n"
 		ask_option no 'Harddrive selection' "Select the hard drive to use" required $(finddisks 1 _) || return 1
 		DISC=$ANSWER_OPTION
+	elif [ -z "$DISCS" ]; then
+            ask_string "Could not find disk. Please enter path of devicefile manually" "" || return 1
+            DISC=$ANSWER_STRING
 	else
 		DISC=$DISCS
 	fi
-
+	# TODO : some checks if $DISC is really a blockdevice is probably a good idea
 	DISC=${DISC// /} # strip all whitespace.  we need this for some reason.TODO: find out why
 
 	get_blockdevice_size $DISC MiB
@@ -430,7 +435,7 @@ interactive_filesystem ()
 		[ $part_type = raw -o $part_type = lvm-lv                          ] && which `get_filesystem_program dm_crypt` &>/dev/null && FSOPTS="$FSOPTS dm_crypt DM_crypt_Volume"
 
 		fs_create=no
-		ask_yesno "Do you want to have this filesystem re(created) ?  If not, make sure there already is a filesystem!" && fs_create=yes
+		ask_yesno "Do you want to have this filesystem (re)created ?  If not, make sure there already is a filesystem!" && fs_create=yes
 
 		# determine FS
 		fsopts=($FSOPTS);
@@ -452,7 +457,7 @@ interactive_filesystem ()
 		then
 			default=no
 			[ -n "$fs_mountpoint" ] && default="$fs_mountpoint"
-			ask_option $default "Select the mountpoint" "Select a mountpoint for $part" required / 'root' /boot 'files for booting' /etc 'config files' /home 'home directories' /tmp 'temporary files' custom 'enter a custom mountpoint' || return 1
+			ask_option $default "Select the mountpoint" "Select a mountpoint for $part" required / 'root' /boot 'files for booting' /home 'home directories' /var 'variable files' /tmp 'temporary files' custom 'enter a custom mountpoint' || return 1
 			fs_mountpoint=$ANSWER_OPTION
 			[ "$default" == 'no' ] && default=
 			if [ "$ANSWER_OPTION" == custom ]
@@ -466,7 +471,13 @@ interactive_filesystem ()
 		then
 			default=
 			[ -n "$fs_label" ] && default="$fs_label"
-			ask_string "Enter the label/name for this $fs_type on $part" "$default" 0 #TODO: check that you can't give LV's labels that have been given already or the installer will break
+			ask_string "Enter the label/name for this $fs_type on $part (Mandatory for this type of FS!)" "$default" || return 1 #TODO: check that you can't give LV's labels that have been given already or the installer will break.
+			fs_label=$ANSWER_STRING
+		elif [ "$fs_create" == yes ] && [ "$fs_type" = ext2 -o "$fs_type" = ext3 -o "$fs_type" = ext4 -o "$fs_type" = reiserfs -o "$fs_type" = xfs -o "$fs_type" = jfs -o "$fs_type" = vfat ]
+		then
+			default=
+			[ -n "$fs_label" ] && default="$fs_label"
+			ask_string "Enter the label for this $fs_type on $part (optional)" "$default" 0
 			fs_label=$ANSWER_STRING
 		fi
 
@@ -767,6 +778,7 @@ Note that right now the packages (and groups) selection is limited to the repos
 
     # sort by group
     _pkglist="$(echo "$_pkglist" | sort -f -k 2)"
+    [ -z "$_pkglist" ] && show_warning "No packages found" "Sorry. I could not find any packages. maybe your network is not setup correctly, you lost connection, no mirror setup, bad group, ..." && return 1
 
     ask_checklist "Select Packages To Install." $_pkglist || return 1
 	var_TARGET_PACKAGES=$ANSWER_CHECKLIST # contains now all package names
@@ -910,7 +922,7 @@ interactive_grub() {
 
         DEVS=$(finddisks 1 _)
         DEVS="$DEVS $(findpartitions 1 _)"
-        if [ "$DEVS" = "" ]; then
+        if [ "$DEVS" = " " ]; then
             notify "No hard drives were found"
             return 1
         fi
@@ -1089,20 +1101,21 @@ generate_grub_menulst() {
 			then
 				debug 'FS' 'Grub kernel line? Found / on dm_crypt on raw'
 				raw_device=`echo "$ANSWER_DEVICES" | sed -n '2p' | cut -d ' ' -f1`
-				kernel="kernel $subdir/vmlinuz26 root=$raw_device ro"
+				crypt_device=`echo "$ANSWER_DEVICES" | sed -n '1p' | cut -d ' ' -f1`
+				kernel="kernel $subdir/vmlinuz26 root=$crypt_device cryptdevice=$raw_device:`basename $crypt_device` ro"
 			elif echo "$ANSWER_DEVICES" | sed -n '1p' | grep -q 'lvm-lv$' && echo "$ANSWER_DEVICES" | sed -n '4p' | grep -q 'dm_crypt$' && echo "$ANSWER_DEVICES" | sed -n '5p' | grep -q 'raw$'
 			then
 				debug 'FS' 'Grub kernel line? Found / on lvm on dm_crypt on raw'
 				lv_device=`echo "$ANSWER_DEVICES" | sed -n '1p' | cut -d ' ' -f1`
-				vg_device=`echo "$ANSWER_DEVICES" | sed -n '2p' | cut -d ' ' -f1`
+				crypt_device=`echo "$ANSWER_DEVICES" | sed -n '4p' | cut -d ' ' -f1`
 				raw_device=`echo "$ANSWER_DEVICES" | sed -n '5p' | cut -d ' ' -f1`
-				kernel="kernel $subdir/vmlinuz26 root=$lv_device cryptdevice=$raw_device:`basename $vg_device` ro"
+				kernel="kernel $subdir/vmlinuz26 root=$lv_device cryptdevice=$raw_device:`basename $crypt_device` ro"
 			elif echo "$ANSWER_DEVICES" | sed -n '1p' | grep -q 'dm_crypt$' && echo "$ANSWER_DEVICES" | sed -n '2p' | grep -q 'lvm-lv$' && echo "$ANSWER_DEVICES" | sed -n '5p' | grep -q 'raw$'
 			then
 				debug 'FS' 'Grub kernel line? Found / on dm_crypt on lvm on raw'
 				crypt_device=`echo "$ANSWER_DEVICES" | sed -n '1p' | cut -d ' ' -f1`
 				lv_device=`echo "$ANSWER_DEVICES" | sed -n '2p' | cut -d ' ' -f1`
-				kernel=" kernel $subdir/vmlinuz26 root=$crypt_device cryptdevice=$lv_device:root ro"
+				kernel="kernel $subdir/vmlinuz26 root=$crypt_device cryptdevice=$lv_device:`basename $crypt_device` ro"
 			elif echo "$ANSWER_DEVICES" | sed -n '1p' | grep -q 'raw$'
 			then
 				debug 'FS' 'Grub kernel line? Found / on raw'
